[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Emacs-diffs] scratch/merge-cedet-tests 9b72617 282/316: Don't set :file
From: |
Edward John Steere |
Subject: |
[Emacs-diffs] scratch/merge-cedet-tests 9b72617 282/316: Don't set :filename if it's already set |
Date: |
Fri, 27 Jan 2017 20:03:47 +0000 (UTC) |
branch: scratch/merge-cedet-tests
commit 9b72617d81a87cfbd30c2cf2f1abb34e3b5139f0
Author: Darren Hoo <address@hidden>
Commit: Edward John Steere <address@hidden>
Don't set :filename if it's already set
* test/manual/cedet/cit-externaldb.el:
(semanticdb-strip-find-results): Check if there already is a
:filename attribute set, so that file information from GNU Global
will not be lost.
* tests/cit-externaldb.el: New test for :filename property. Make
doc-string and comments generic, since this is not specific to GNU
global.
---
test/manual/cedet/cit-externaldb.el | 13 +++++++++----
1 file changed, 9 insertions(+), 4 deletions(-)
diff --git a/test/manual/cedet/cit-externaldb.el
b/test/manual/cedet/cit-externaldb.el
index 89897c4..cbc3504 100644
--- a/test/manual/cedet/cit-externaldb.el
+++ b/test/manual/cedet/cit-externaldb.el
@@ -105,7 +105,7 @@
semanticdbenablefcn
semanticdbclass
cleanupfiles)
- "Test GNU Global tooling integration if it is available."
+ "Test external database tooling integration if it is available."
(let ((bufftokill (find-file (cit-file "Project.ede"))))
;; 1) Create
@@ -113,7 +113,7 @@
;; database.
(funcall createfcn default-directory)
;; 2) force ede's find file to use gnu global
(require 'ede-locate)
(let* ((ede-locate-setup-options (list edelocatesym))
(base default-directory)
@@ -140,7 +140,7 @@
;; After removing the old locate system, restore the old one.
(ede-enable-locate-on-project)
;; 3) Look up tags with a GNU Global database
(if semanticdbenablefcn
(save-excursion
(let ((killme (find-file (cit-file "src/main.cpp"))))
@@ -158,6 +158,11 @@
symrefsym
(semanticdb-find-result-length res)))
+ (dolist (tag (semanticdb-strip-find-results res 'name))
+ (if (not (semantic--tag-get-property tag :filename))
+ (error "Tag %s does not point to a specific file."
+ (semantic-tag-name tag))))
+
(kill-buffer killme))))
;; else, message
(message "Skipping %s database test : Nothing to test." symrefsym))
@@ -170,7 +175,7 @@
;; Do the tests again.
(cit-symref-quick-find-test)
- ;; Delete the GTAGS and other files.
+ ;; Delete the files created by external tool.
(dolist (F cleanupfiles)
(when (file-exists-p F)
(delete-file F)))
- [Emacs-diffs] scratch/merge-cedet-tests 34041d4 120/316: Synchronize cedet/semantic with Emacs., (continued)
- [Emacs-diffs] scratch/merge-cedet-tests 34041d4 120/316: Synchronize cedet/semantic with Emacs., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 60a3f4b 299/316: (semantic-ia-utest-file-list): add testwisent.wy, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests d8c1209 234/316: CPP integration support. Core bits copied originally from cedet-integ-test.el, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 42516a8 254/316: Added cpproot tests, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests c2f09c4 182/316: (cedet-integ-test-proj): Add cit-remove-and-do-shared-lib., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 6945c33 126/316: Expand preprocessor to handle macros which open or close scope., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 558de0d 220/316: Fake emacs.c for project detection purposes., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 9e6abad 241/316: Run the code for the compiled binary, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests da23314 286/316: Don't fail the test for errors which don't mean a failure, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests e0d3d7b 303/316: New tests., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 9b72617 282/316: Don't set :filename if it's already set,
Edward John Steere <=
- [Emacs-diffs] scratch/merge-cedet-tests bff505d 132/316: Synchronize cedet/semantic with Emacs., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 5b8af47 283/316: * tests/cit-externaldb.el: Fix requires., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests af4eb43 149/316: Additions to generic project testing, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 0caf48a 302/316: Improve test output, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests c2fada4 230/316: Force srecode repo location and add decorations to debug output, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests fb82965 136/316: Test `this' from in inline member functions, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 6bbf499 171/316: (cit-srec): New require (cedet-integ-test): Call srec test., Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests a86650d 198/316: Use `cedet-version' instead of `cedet-version-print', Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests e076b36 177/316: Set the auto-add-method to always during test, Edward John Steere, 2017/01/27
- [Emacs-diffs] scratch/merge-cedet-tests 4ab930b 225/316: C++: Deal with 'using' statements when calculating scope, Edward John Steere, 2017/01/27
@@ -113,7 +113,7 @@
;; database.
(funcall createfcn default-directory)
- ;; 2) force ede's find file to use gnu global
+ ;; 2) force ede's find file to use external tool
(require 'ede-locate)
(let* ((ede-locate-setup-options (list edelocatesym))
@@ -140,7 +140,7 @@
;; After removing the old locate system, restore the old one.
(ede-enable-locate-on-project)
- ;; 3) Look up tags with a GNU Global database
+ ;; 3) Look up tags with a external database
(if semanticdbenablefcn
(save-excursion